@@ -1,3 +1,4 @@
+import cfdm
 import numpy as np
 
 from ...constants import _stash2standard_name
@@ -8,22 +9,19 @@ from ...functions import (
     parse_indices,
 )
 from ...umread_lib.umfile import File, Rec
-from .abstract import FileArray
+from .abstract import Array
+from .mixin import FileArrayMixin
 
 
-class UMArray(FileArray):
+class UMArray(FileArrayMixin, cfdm.data.mixin.FileArrayMixin, Array):
     """A sub-array stored in a PP or UM fields file."""
 
     def __init__(
         self,
         filename=None,
+        address=None,
         dtype=None,
-        ndim=None,
         shape=None,
-        size=None,
-        header_offset=None,
-        data_offset=None,
-        disk_length=None,
         fmt=None,
         word_size=None,
         byte_ordering=None,
@@ -36,8 +34,13 @@ class UMArray(FileArray):
 
         :Parameters:
 
-            filename: `str`
-                The file name in normalized, absolute form.
+            filename: (sequence of) `str`, optional
+                The file name(s).
+
+            address: (sequence of) `int`, optional
+                The start position in the file(s) of the header(s).
+
+                .. versionadded:: 3.15.0
 
             dtype: `numpy.dtype`
                 The data type of the data array on disk.
@@ -49,17 +52,6 @@ class UMArray(FileArray):
                 dimensions. When read, the data on disk is reshaped to
                 *shape*.
 
-            header_offset: `int`
-                The start position in the file of the header.
-
-            data_offset: `int`, optional
-                The start position in the file of the data array.
-
-            disk_length: `int`, optional
-                The number of words on disk for the data array,
-                usually LBLREC-LBEXT. If set to ``0`` then `!size` is
-                used.
-
             fmt: `str`, optional
                 ``'PP'`` or ``'FF'``
 
@@ -69,18 +61,6 @@ class UMArray(FileArray):
             byte_ordering: `str`, optional
                 ``'little_endian'`` or ``'big_endian'``
 
-            size: `int`
-                Deprecated at version 3.14.0. If set will be
-                ignored.
-
-                Number of elements in the uncompressed array.
-
-            ndim: `int`
-                Deprecated at version 3.14.0. If set will be
-                ignored.
-
-                The number of uncompressed array dimensions.
-
             units: `str` or `None`, optional
                 The units of the fragment data. Set to `None` to
                 indicate that there are no units. If unset then the
@@ -96,6 +76,22 @@ class UMArray(FileArray):
 
             {{init copy: `bool`, optional}}
 
+            size: `int`
+                Deprecated at version 3.14.0.
+
+            ndim: `int`
+                Deprecated at version 3.14.0.
+
+            header_offset: `int`
+                Deprecated at version 3.15.0. use the *address*
+                parameter instead.
+
+            data_offset: `int`, optional
+                Deprecated at version 3.15.0.
+
+            disk_length: `int`, optional
+                Deprecated at version 3.15.0.
+
         """
         super().__init__(source=source, copy=copy)
 
@@ -110,26 +106,16 @@ class UMArray(FileArray):
             except AttributeError:
                 filename = None
 
+            try:
+                address = source._get_component("address", None)
+            except AttributeError:
+                address = None
+
             try:
                 fmt = source._get_component("fmt", None)
             except AttributeError:
                 fmt = None
 
-            try:
-                disk_length = source._get_component("disk_length", None)
-            except AttributeError:
-                disk_length = None
-
-            try:
-                header_offset = source._get_component("header_offset", None)
-            except AttributeError:
-                header_offset = None
-
-            try:
-                data_offset = source._get_component("data_offset", None)
-            except AttributeError:
-                data_offset = None
-
             try:
                 dtype = source._get_component("dtype", None)
             except AttributeError:
@@ -155,12 +141,24 @@ class UMArray(FileArray):
             except AttributeError:
                 calendar = False
 
+        if filename is not None:
+            if isinstance(filename, str):
+                filename = (filename,)
+            else:
+                filename = tuple(filename)
+
+            self._set_component("filename", filename, copy=False)
+
+        if address is not None:
+            if isinstance(address, int):
+                address = (address,)
+            else:
+                address = tuple(address)
+
+            self._set_component("address", address, copy=False)
+
         self._set_component("shape", shape, copy=False)
-        self._set_component("filename", filename, copy=False)
         self._set_component("dtype", dtype, copy=False)
-        self._set_component("header_offset", header_offset, copy=False)
-        self._set_component("data_offset", data_offset, copy=False)
-        self._set_component("disk_length", disk_length, copy=False)
         self._set_component("units", units, copy=False)
         self._set_component("calendar", calendar, copy=False)
 
@@ -184,15 +182,15 @@ class UMArray(FileArray):
         Returns a subspace of the array as an independent numpy array.
 
         """
-        f = self.open()
-        rec = self._get_rec(f)
+        f, header_offset = self.open()
+        rec = self._get_rec(f, header_offset)
 
         int_hdr = rec.int_hdr
         real_hdr = rec.real_hdr
         array = rec.get_data().reshape(self.shape)
 
         self.close(f)
-        del f
+        del f, rec
 
         if indices is not Ellipsis:
             indices = parse_indices(array.shape, indices)
@@ -252,7 +250,7 @@ class UMArray(FileArray):
         # Return the numpy array
         return array
 
-    def _get_rec(self, f):
+    def _get_rec(self, f, header_offset):
         """Get a container for a record.
 
         This includes the lookup header and file offsets.
@@ -266,27 +264,30 @@ class UMArray(FileArray):
             f: `umread_lib.umfile.File`
                 The open PP or FF file.
 
+            header_offset: `int`
+
         :Returns:
 
             `umread_lib.umfile.Rec`
                 The record container.
 
         """
-        header_offset = self.header_offset
-        data_offset = self.data_offset
-        disk_length = self.disk_length
-        if data_offset is None or disk_length is None:
-            # This method doesn't require data_offset and disk_length,
-            # so plays nicely with CFA. Is it fast enough that we can
-            # use this method always?
-            for v in f.vars:
-                for r in v.recs:
-                    if r.hdr_offset == header_offset:
-                        return r
-        else:
-            return Rec.from_file_and_offsets(
-                f, header_offset, data_offset, disk_length
-            )
+        return Rec.from_file_and_offsets(f, header_offset)
+
+        # ------------------------------------------------------------
+        # Leave the following commented code here for debugging
+        # purposes. Replacing the above line with this code moves the
+        # calculation of the data offset and disk length from pure
+        # Python to the C library, at the expense of completely
+        # parsing the file. Note: If you do replace the above line
+        # with the commented code, then you *must* also set
+        # 'parse=True' in the `open` method.
+        # ------------------------------------------------------------
+
+        # for v in f.vars:
+        #     for r in v.recs:
+        #         if r.hdr_offset == header_offset:
+        #             return r
 
     def _set_units(self, int_hdr):
         """The units and calendar properties.
@@ -473,10 +474,17 @@ class UMArray(FileArray):
 
         :Returns:
 
-            `int`
+            `int` or `None`
+                The address, or `None` if there isn't one.
 
         """
-        return self._get_component("header_offset")
+        _DEPRECATION_ERROR_ATTRIBUTE(
+            self,
+            "header_offset",
+            "Use method 'get_address' instead.",
+            version="3.15.0",
+            removed_at="5.0.0",
+        )  # pragma: no cover
 
     @property
     def data_offset(self):
@@ -487,7 +495,12 @@ class UMArray(FileArray):
             `int`
 
         """
-        return self._get_component("data_offset")
+        _DEPRECATION_ERROR_ATTRIBUTE(
+            self,
+            "data_offset",
+            version="3.15.0",
+            removed_at="5.0.0",
+        )  # pragma: no cover
 
     @property
     def disk_length(self):
@@ -498,7 +511,12 @@ class UMArray(FileArray):
             `int`
 
         """
-        return self._get_component("disk_length")
+        _DEPRECATION_ERROR_ATTRIBUTE(
+            self,
+            "disk_length",
+            version="3.15.0",
+            removed_at="5.0.0",
+        )  # pragma: no cover
 
     @property
     def fmt(self):
@@ -581,21 +599,6 @@ class UMArray(FileArray):
         if self._get_component("close"):
             f.close_fd()
 
-    def get_address(self):
-        """The address in the file of the variable.
-
-        The address is the word offset of the lookup header.
-
-        .. versionadded:: 3.14.0
-
-        :Returns:
-
-            `str` or `None`
-                The address, or `None` if there isn't one.
-
-        """
-        return self.header_offset
-
     def get_byte_ordering(self):
         """The endianness of the data.
 
@@ -633,6 +636,26 @@ class UMArray(FileArray):
         """
         return self._get_component("fmt", None)
 
+    def get_format(self):
+        """The format of the files.
+
+        .. versionadded:: 3.15.0
+
+        .. seealso:: `get_address`, `get_filename`, `get_formats`
+
+        :Returns:
+
+            `str`
+                The file format. Always ``'um'``, signifying PP/UM.
+
+        **Examples**
+
+        >>> a.get_format()
+        'um'
+
+        """
+        return "um"
+
     def get_word_size(self):
         """Word size in bytes.
 
@@ -652,30 +675,24 @@ class UMArray(FileArray):
         return self._get_component("word_size", None)
 
     def open(self):
-        """Returns an open dataset containing the data array.
+        """Returns an open dataset and the address of the data.
 
         :Returns:
 
-            `umfile_lib.File`
+            `umfile_lib.umfile.File`, `int`
+                The open file object, and the start address in bytes
+                of the lookup header.
 
         **Examples**
 
         >>> f.open()
+        (<cf.umread_lib.umfile.File object at 0x7fdc25056380>, 4)
 
         """
-        try:
-            f = File(
-                path=self.get_filename(),
-                byte_ordering=self.get_byte_ordering(),
-                word_size=self.get_word_size(),
-                fmt=self.get_fmt(),
-            )
-        except Exception as error:
-            try:
-                f.close_fd()
-            except Exception:
-                pass
-
-            raise Exception(error)
-        else:
-            return f
+        return super().open(
+            File,
+            byte_ordering=self.get_byte_ordering(),
+            word_size=self.get_word_size(),
+            fmt=self.get_fmt(),
+            parse=False,
+        )
