@@ -5,7 +5,9 @@ from glob import glob
 from numbers import Integral
 from os.path import isdir
 from re import Pattern
+from urllib.parse import urlparse
 
+from cfdm import is_log_level_info
 from numpy.ma.core import MaskError
 
 from ..aggregate import aggregate as cf_aggregate
@@ -778,10 +780,11 @@ def read(
     # Manage input parameters where contradictions are possible:
     if cdl_string and fmt:
         if fmt == "CDL":
-            logger.info(
-                "It is not necessary to set the cf.read fmt as 'CDL' when "
-                "cdl_string is True, since that implies CDL is the format."
-            )  # pragma: no cover
+            if is_log_level_info(logger):
+                logger.info(
+                    "It is not necessary to set the cf.read fmt as 'CDL' when "
+                    "cdl_string is True, since that implies CDL is the format."
+                )  # pragma: no cover
         else:
             raise ValueError(
                 "cdl_string can only be True when the format is CDL, though "
@@ -795,6 +798,8 @@ def read(
             f"when recursive={recursive!r}"
         )
 
+    info = is_log_level_info(logger)
+
     # Parse the 'cfa' parameter
     if cfa is None:
         cfa_options = {}
@@ -879,7 +884,8 @@ def read(
         # Expand variables
         file_glob = os.path.expanduser(os.path.expandvars(file_glob))
 
-        if file_glob.startswith("http://"):
+        scheme = urlparse(file_glob).scheme
+        if scheme in ("https", "http"):
             # Do not glob a URL
             files2 = (file_glob,)
         else:
@@ -905,7 +911,8 @@ def read(
             files2 = files3
 
         for filename in files2:
-            logger.info(f"File: {filename}")  # pragma: no cover
+            if info:
+                logger.info(f"File: {filename}")  # pragma: no cover
 
             if um:
                 ftype = "UM"
@@ -965,10 +972,11 @@ def read(
             field_counter = len(out)
             file_counter += 1
 
-    logger.info(
-        f"Read {field_counter} field{_plural(field_counter)} from "
-        f"{file_counter} file{_plural(file_counter)}"
-    )  # pragma: no cover
+    if info:
+        logger.info(
+            f"Read {field_counter} field{_plural(field_counter)} from "
+            f"{file_counter} file{_plural(file_counter)}"
+        )  # pragma: no cover
 
     # ----------------------------------------------------------------
     # Aggregate the output fields/domains
@@ -979,10 +987,11 @@ def read(
         out = cf_aggregate(out, **aggregate_options)
 
         n = len(out)  # pragma: no cover
-        logger.info(
-            f"{org_len} input field{_plural(org_len)} aggregated into "
-            f"{n} field{ _plural(n)}"
-        )  # pragma: no cover
+        if info:
+            logger.info(
+                f"{org_len} input field{_plural(org_len)} aggregated into "
+                f"{n} field{_plural(n)}"
+            )  # pragma: no cover
 
     # ----------------------------------------------------------------
     # Sort by netCDF variable name
