@@ -354,6 +354,52 @@ class functionTest(unittest.TestCase):
     def test_CFA(self):
         self.assertEqual(cf.CFA(), cf.__cfa_version__)
 
+    def test_normalize_slice(self):
+        self.assertEqual(cf.normalize_slice(slice(1, 4), 8), slice(1, 4, 1))
+        self.assertEqual(cf.normalize_slice(slice(None), 8), slice(0, 8, 1))
+        self.assertEqual(
+            cf.normalize_slice(slice(6, None, -1), 8), slice(6, None, -1)
+        )
+        self.assertEqual(cf.normalize_slice(slice(-2, 4), 8), slice(6, 4, 1))
+
+        # Cyclic slices
+        self.assertEqual(
+            cf.normalize_slice(slice(-2, 3), 8, cyclic=True), slice(-2, 3, 1)
+        )
+        self.assertEqual(
+            cf.normalize_slice(slice(6, 3), 8, cyclic=True), slice(-2, 3, 1)
+        )
+        self.assertEqual(
+            cf.normalize_slice(slice(6, 3, 2), 8, cyclic=True), slice(-2, 3, 2)
+        )
+
+        self.assertEqual(
+            cf.normalize_slice(slice(2, -3, -1), 8, cyclic=True),
+            slice(2, -3, -1),
+        )
+        self.assertEqual(
+            cf.normalize_slice(slice(2, 5, -1), 8, cyclic=True),
+            slice(2, -3, -1),
+        )
+        self.assertEqual(
+            cf.normalize_slice(slice(2, 5, -2), 8, cyclic=True),
+            slice(2, -3, -2),
+        )
+
+        with self.assertRaises(IndexError):
+            cf.normalize_slice([1, 2], 8)
+
+        for index in (
+            slice(1, 6),
+            slice(6, 1, -1),
+            slice(None, 4, None),
+            slice(1, 6, 0),
+            [1, 2],
+            5,
+        ):
+            with self.assertRaises(IndexError):
+                cf.normalize_slice(index, 8, cyclic=True)
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
